@@ -28,7 +28,7 @@
 * Mime Decoding class
 *
 * This class will parse a raw mime email and return
-* the structure. Returned structure is similar to 
+* the structure. Returned structure is similar to
 * that returned by imap_fetchstructure().
 *
 * USAGE: (assume $input is your raw email)
@@ -106,7 +106,7 @@ class Mail_mimeDecode {
 
     /**
      * Constructor.
-     * 
+     *
      * Sets up the object, initialise the variables, and splits and
      * stores the header and body of the input.
      *
@@ -130,7 +130,7 @@ class Mail_mimeDecode {
      * Begins the decoding process. If called statically
      * it will create an object and call the decode() method
      * of it.
-     * 
+     *
      * @param array An array of various parameters that determine
      *              various things:
      *              include_bodies - Whether to include the body in the returned
@@ -151,7 +151,7 @@ class Mail_mimeDecode {
         $isStatic = !(isset($this) && get_class($this) == __CLASS__);
 
         // Have we been called statically?
-	// If so, create an object and pass details to that.
+    // If so, create an object and pass details to that.
         if ($isStatic AND isset($params['input'])) {
 
             $obj = new Mail_mimeDecode($params['input'], $params['crlf']);
@@ -159,16 +159,17 @@ class Mail_mimeDecode {
 
         // Called statically but no input
         } elseif ($isStatic) {
-            return PEAR::raiseError('Called statically and no input given');
+            debugLog('MimeDecode called statically and no input given');
+            return false;
 
         // Called via an object
         } else {
             $this->_include_bodies = isset($params['include_bodies']) ?
-	                             $params['include_bodies'] : false;
+                                 $params['include_bodies'] : false;
             $this->_decode_bodies  = isset($params['decode_bodies']) ?
-	                             $params['decode_bodies']  : false;
+                                 $params['decode_bodies']  : false;
             $this->_decode_headers = isset($params['decode_headers']) ?
-	                             $params['decode_headers'] : false;
+                                 $params['decode_headers'] : false;
             $this->_charset = isset($params['charset']) ?
                                  $params['charset'] : 'iso-8859-15';
 
@@ -185,7 +186,7 @@ class Mail_mimeDecode {
      * Performs the decoding. Decodes the body string passed to it
      * If it finds certain content-types it will call itself in a
      * recursive fashion
-     * 
+     *
      * @param string Header section
      * @param string Body section
      * @return object Results of decoding process
@@ -216,12 +217,12 @@ class Mail_mimeDecode {
 
                 case 'content-type':
                     $content_type = $this->_parseHeaderValue($headers[$key]['value']);
-    
+
                     if (preg_match('/([0-9a-z+.-]+)\/([0-9a-z+.-]+)/i', $content_type['value'], $regs)) {
                         $return->ctype_primary   = $regs[1];
                         $return->ctype_secondary = $regs[2];
                     }
-    
+
                     if (isset($content_type['other'])) {
                         while (list($p_name, $p_value) = each($content_type['other'])) {
                             $return->ctype_parameters[$p_name] = $p_value;
@@ -246,7 +247,7 @@ class Mail_mimeDecode {
         }
 
         if (isset($content_type)) {
-        
+
             $cte = isset($content_transfer_encoding['value']) ? $content_transfer_encoding['value'] : '7bit';
 
             switch (strtolower($content_type['value'])) {
@@ -254,7 +255,7 @@ class Mail_mimeDecode {
                     $charset = isset($return->ctype_parameters['charset']) ? $return->ctype_parameters['charset'] : 'iso-8859-15';
                     $this->_include_bodies ? $return->body = ($this->_decode_bodies ? $this->_decodeBody($body, $cte, $charset) : $body) : null;
                     break;
-    
+
                 case 'text/html':
                     $charset = isset($return->ctype_parameters['charset']) ? $return->ctype_parameters['charset'] : 'iso-8859-15';
                     $this->_include_bodies ? $return->body = ($this->_decode_bodies ? $this->_decodeBody($body, $cte, $charset) : $body) : null;
@@ -269,7 +270,7 @@ class Mail_mimeDecode {
                         $this->_error = 'No boundary found for ' . $content_type['value'] . ' part';
                         return false;
                     }
-                    
+
                     $default_ctype = (strtolower($content_type['value']) === 'multipart/digest') ? 'message/rfc822' : 'text/plain';
 
                     $parts = $this->_boundarySplit($body, $content_type['other']['boundary']);
@@ -299,7 +300,7 @@ class Mail_mimeDecode {
             $return->ctype_secondary = $ctype[1];
             $this->_include_bodies ? $return->body = ($this->_decode_bodies ? $this->_decodeBody($body) : $body) : null;
         }
-        
+
         return $return;
     }
 
@@ -307,7 +308,7 @@ class Mail_mimeDecode {
      * Given a string containing a header and body
      * section, this function will split them (at the first
      * blank line) and return them.
-     * 
+     *
      * @param string Input to split apart
      * @return array Contains header and body section
      * @access private
@@ -319,6 +320,10 @@ class Mail_mimeDecode {
             $this->_error = 'Could not split header and body';
             return false;
         }
+        //android fix
+        if (($pos+(2*strlen($this->_crlf))) == strlen($input)) {
+            $pos = strpos ($input, "\n\r") - 1;
+        }
 
         $header = substr($input, 0, $pos);
         $body   = substr($input, $pos+(2*strlen($this->_crlf)));
@@ -329,7 +334,7 @@ class Mail_mimeDecode {
     /**
      * Parse headers given in $input and return
      * as assoc array.
-     * 
+     *
      * @param string Headers to parse
      * @return array Contains parsed headers
      * @access private
@@ -339,9 +344,16 @@ class Mail_mimeDecode {
 
         if ($input !== '') {
             // Unfold the input
-            $input   = preg_replace('/' . $this->_crlf . "(\t| )/", ' ', $input);
-            $headers = explode($this->_crlf, trim($input));
-    
+            //android fix
+
+            if (substr_count($input, "\r\n") == 0 && substr_count($input, "\n") > 0) {
+                $input  = preg_replace('/' . "\n(\t| )/", ' ', $input);
+                $headers = explode("\n", trim($input));
+            }
+            else {
+                $input  = preg_replace('/' . $this->_crlf . "(\t| )/", ' ', $input);
+                $headers = explode($this->_crlf, trim($input));
+            }
             foreach ($headers as $value) {
                 $hdr_name = substr($value, 0, $pos = strpos($value, ':'));
                 $hdr_value = substr($value, $pos+1);
@@ -363,7 +375,7 @@ class Mail_mimeDecode {
      * parts (after ;) This function is not as
      * robust as it could be. Eg. header comments
      * in the wrong place will probably break it.
-     * 
+     *
      * @param string Header value to parse
      * @return array Contains parsed result
      * @access private
@@ -387,14 +399,14 @@ class Mail_mimeDecode {
         } else {
             $return['value'] = trim($input);
         }
-        
+
         return $return;
     }
 
     /**
      * This function splits the input based
      * on the given boundary
-     * 
+     *
      * @param string Input to parse
      * @return array Contains array of resulting mime parts
      * @access private
@@ -402,7 +414,7 @@ class Mail_mimeDecode {
     function _boundarySplit($input, $boundary)
     {
         $tmp = explode('--'.$boundary, $input);
-		$parts = array();
+        $parts = array();
         for ($i=1; $i<count($tmp)-1; $i++) {
             $parts[] = $tmp[$i];
         }
@@ -448,12 +460,12 @@ class Mail_mimeDecode {
 
             $input = str_replace($encoded, $this->_fromCharset($charset, $text), $input);
         }
-        
+
         return $input;
     }
 
     /**
-     * Given a body string and an encoding type, 
+     * Given a body string and an encoding type,
      * this function will decode and return it.
      *
      * @param  string Input body to decode
@@ -508,11 +520,11 @@ class Mail_mimeDecode {
 
         return $input;
     }
-    
+
     function _fromCharset($charset, $input) {
         if($charset == '')
             return $input;
-            
+
         return iconv($charset, $this->_charset, $input);
     }
 
